{ "locations": [ { "id": 136, "name": "Downtown", "address": "9303 Lyon Drive, Hill Valley, CA 12345", "coordinates": [ "34.2390664", "-118.4332328" ], "created_at": "Sat, 26 Oct 1985 01:20:00 -0500", "updated_at": "Wed, Oct 21 2015 16:29:00 -0500", "place": "" }, { "id": 137, "name": "Uptown", "address": "100 Courthouse Square, Hill Valley, CA 12345", "coordinates": [ "34.141362", "-118.349732" ], "created_at": "Sat, 26 Oct 1985 01:20:00 -0500", "updated_at": "Wed, Oct 21 2015 16:29:00 -0500", "place": { "business_name": "When I Work", "address": "60 Plato Blvd, St Paul, MN 55107, United States", "place_id": "ChIJYfRBzjfVslIRQLB018IGX3o", "place_type": "point_of_interest,establishment", "latitude": "44.93739849", "longitude": "-93.0843011" } } ] }